@@ -13,8 +13,10 @@
 #undef HAVE_IEEEFP_H
 #undef ENABLE_GNOME
 #undef HAVE_GLIBWWW
+#undef HAVE_GHTTP
 #undef HAVE_GNU_REGEX
 #undef USING_OAF
+#undef GTK_HTML_USE_XIM
 
 @BOTTOM@
 /* This is from libglade */
