@@ -23,18 +23,9 @@
 #ifndef _GTK_HTML_LINK_H_
 #define _GTK_HTML_LINK_H_
 
-typedef struct _GtkHTMLLinkDialog GtkHTMLLinkDialog;
-
 #include <gnome.h>
-#include <htmllinktextmaster.h>
 #include "control-data.h"
 
-GtkHTMLLinkDialog * gtk_html_link_dialog_new     (GtkHTML *html);
-void                gtk_html_link_dialog_destroy (GtkHTMLLinkDialog *);
-
-void                link_insert                  (GtkHTMLControlData *cd);
-void                link_edit                    (GtkHTMLControlData *cd, HTMLLinkTextMaster *link);
-
 GtkWidget             * link_properties      (GtkHTMLControlData *cd, gpointer *set_data);
 void                    link_apply_cb        (GtkHTMLControlData *cd, gpointer  get_data);
 void                    link_close_cb        (GtkHTMLControlData *cd, gpointer  get_data);
