@@ -21,6 +21,7 @@
 #ifndef HTMLEMBEDDED_H
 #define HTMLEMBEDDED_H
 
+#include <gtk/gtkwidget.h>
 #include "htmlobject.h"
 
 #define HTML_EMBEDDED(x) ((HTMLEmbedded *)(x))
@@ -32,7 +33,7 @@ struct _HTMLEmbedded {
 	gchar *name;
 	gchar *value;
 	HTMLForm *form;
-	GtkWidget *widget, *parent;
+	GtkWidget *widget, *parent;	
 	gint width, height;
 
 	gint abs_x, abs_y;
@@ -40,7 +41,8 @@ struct _HTMLEmbedded {
 
 struct _HTMLEmbeddedClass {
 	HTMLObjectClass object_class;
-
+	
+		    
 	void (*reset) (HTMLEmbedded *element);
 	gchar *(*encode) (HTMLEmbedded *element);
 };
@@ -60,6 +62,7 @@ void          html_embedded_init           (HTMLEmbedded      *element,
 					    gchar             *value);
 void          html_embedded_set_widget     (HTMLEmbedded      *element,
 					    GtkWidget         *widget);
+GtkWidget    *html_embedded_get_widget     (HTMLEmbedded      *element);
 gchar        *html_embedded_get_name       (HTMLEmbedded      *element);
 void          html_embedded_set_form       (HTMLEmbedded      *element,
 					    HTMLForm          *form);
@@ -68,6 +71,5 @@ gchar        *html_embedded_encode         (HTMLEmbedded      *element);
 gchar        *html_embedded_encode_string  (gchar             *str);
 HTMLEmbedded *html_embedded_new_widget     (GtkWidget         *parent,
 					    GtkHTMLEmbedded   *eb);
-void          html_embedded_size_recalc    (HTMLEmbedded      *em);
 
 #endif /* HTMLEMBEDDED_H */
