@@ -33,7 +33,10 @@
 
 #include <config.h>
 #include <glib.h>
+#include <string.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtksignal.h>
 
 #include "gtkhtml.h"
 #include "gtkhtml-properties.h"
