@@ -97,7 +97,9 @@ struct _HTMLObjectClass {
 					  guint      *len);
 	gboolean     (* merge)           (HTMLObject *self,
 					  HTMLObject *o,
-					  HTMLEngine *e);
+					  HTMLEngine *e,
+					  GList      *left,
+					  GList      *right);
 	void         (* remove_child)    (HTMLObject *self,
 					  HTMLObject *child);
 	void         (* split)           (HTMLObject *self,
@@ -228,7 +230,8 @@ struct _HTMLObjectClass {
 	HTMLObject * (* remove_link)     (HTMLObject *self, HTMLColor *color);
 
 	/* length */
-	guint        (* get_length)      (HTMLObject *self);
+	guint        (* get_length)                (HTMLObject *self);
+	guint        (* get_recursive_length)      (HTMLObject *self);
 
 	/* movement */
 	HTMLObject * (* next)            (HTMLObject *self, HTMLObject *child);
@@ -269,7 +272,9 @@ HTMLObject     *html_object_op_cut                (HTMLObject            *self,
 						   guint                 *len);
 gboolean        html_object_merge                 (HTMLObject            *self,
 						   HTMLObject            *with,
-						   HTMLEngine            *e);
+						   HTMLEngine            *e,
+						   GList                 *left,
+						   GList                 *right);
 void            html_object_remove_child          (HTMLObject            *self,
 						   HTMLObject            *child);
 void            html_object_split                 (HTMLObject            *self,
@@ -308,6 +313,8 @@ HTMLObject     *html_object_next_by_type          (HTMLObject            *self,
 						   HTMLType               t);
 HTMLObject     *html_object_prev_by_type          (HTMLObject            *self,
 						   HTMLType               t);
+HTMLObject     *html_object_nth_parent            (HTMLObject            *self,
+						   gint                   n);
 /* do search request on object using info */
 gboolean        html_object_search                (HTMLObject            *self,
 						   HTMLSearch            *info);
@@ -401,6 +408,7 @@ void            html_object_get_cursor_base       (HTMLObject            *obj,
 						   gint                  *x,
 						   gint                  *y);
 guint           html_object_get_length            (HTMLObject            *self);
+guint           html_object_get_recursive_length  (HTMLObject            *self);
 guint           html_object_get_bytes             (HTMLObject            *self);
 guint           html_object_get_index             (HTMLObject            *self,
 						   guint                  offset);
@@ -437,6 +445,10 @@ HTMLObject     *html_object_prev_leaf_not_type    (HTMLObject            *self,
 						   HTMLType               t);
 HTMLObject     *html_object_get_head_leaf         (HTMLObject            *o);
 HTMLObject     *html_object_get_tail_leaf         (HTMLObject            *o);
+HTMLObject     *html_object_next_cursor           (HTMLObject            *self,
+						   gint                  *offset);
+HTMLObject     *html_object_prev_cursor           (HTMLObject            *self,
+						   gint                  *offset);
 
 /* Page splitting.  */
 gint  html_object_check_page_split  (HTMLObject *self,
